@@ -265,7 +265,7 @@ KMouseTool::KMouseTool(QWidget *parent, const char *name) :
 	mousetool_just_started = true;
 
 	startTimer(100);
-	trayIcon = new KMouseToolTray (this, "systemTrayIcon");
+	trayIcon = new KMouseToolTray (this);
 	updateStartStopText ();
 	connect(trayIcon, SIGNAL(startStopSelected()), this, SLOT(startStopSelected()));
 	connect(trayIcon, SIGNAL(configureSelected()), this, SLOT(configureSelected()));
@@ -383,7 +383,7 @@ void KMouseTool::setAutostart (bool start)
 	}
 	else {
 	if (fi.exists()) 			// if it exists, delete it
-		cmd = QString("rm -f %s").arg(sym);
+		cmd = QString("rm -f %1").arg(sym);
 	}
 	system(cmd.toAscii());
 }
@@ -592,10 +592,9 @@ void KMouseTool::aboutSelected()
 
 
 
-KMouseToolTray::KMouseToolTray (QWidget *parent, const char *name) : KSystemTrayIcon (parent)
+KMouseToolTray::KMouseToolTray (QWidget *parent) : KStatusNotifierItem(parent)
 {
-	setObjectName(name);
-
+	setStatus(KStatusNotifierItem::Active);
 	startStopAct = contextMenu()->addAction (i18nc("Start tracking the mouse", "&Start"), this, SIGNAL(startStopSelected()));
 	contextMenu()->addSeparator();
         QAction* act;
@@ -623,6 +622,5 @@ void KMouseToolTray::updateStartStopText(bool mousetool_is_running)
                 startStopAct->setText(i18nc("Start tracking the mouse", "&Start"));
 		icon = KIconLoader::global()->loadIcon("kmousetool_off", KIconLoader::Small);
 	}
-	setIcon (icon);
-	show();
+	setIconByPixmap (icon);
 }
