@@ -1,9 +1,3 @@
-/**********************
-  #FILENAME: #FILEDESC
-  #COPYRIGHTNOTICE
-  #LICENSE
-***********************/
-
 #include <QtCore/QTextStream>
 
 #include <kapplication.h>
@@ -23,7 +17,7 @@ int main(int argc, char *argv[])
     KAboutData aboutdata(
         "testfilter", 0, ki18n("testfilter"),
         "0.1.0", ki18n("A utility for testing KTTSD filter plugins."),
-         KAboutData::License_GPL, ki18n("Copyright 2005, Gary Cramblitt <garycramblitt@comcast.net>"));
+         KAboutData::License_GPL, ki18n("Copyright 2005, Gary Cramblitt &lt;garycramblitt@comcast.net&gt;"));
     aboutdata.addAuthor(ki18n("Gary Cramblitt"), ki18n("Maintainer"),"garycramblitt@comcast.net");
 
     KCmdLineArgs::init( argc, argv, &aboutdata );
