@@ -173,27 +173,27 @@ bool StringReplacerProc::init(KConfig* c, const QString& configGroup){
  * @param appId             The DCOP appId of the application that queued the text.
  *                          Also useful for hints about how to do the filtering.
  */
-/*virtual*/ QString StringReplacerProc::convert(const QString& inputText, TalkerCode* talkerCode,
+/*virtual*/ QString StringReplacerProc::convert(const QString& inputText, TalkerCode* /*talkerCode*/,
     const QString& appId)
 {
     m_wasModified = false;
     // If language doesn't match, return input unmolested.
-    if ( !m_languageCodeList.isEmpty() )
-    {
-        QString languageCode = talkerCode->languageCode();
-        //kDebug() << "StringReplacerProc::convert: converting " << inputText <<
-        //    " if language code " << languageCode << " matches " << m_languageCodeList << endl;
-        if ( !m_languageCodeList.contains( languageCode ) )
-        {
-            if ( !talkerCode->countryCode().isEmpty() )
-            {
-                languageCode += '_' + talkerCode->countryCode();
-                 //kDebug() << "StringReplacerProc::convert: converting " << inputText << 
-                 //   " if language code " << languageCode << " matches " << m_languageCodeList << endl;
-                if ( !m_languageCodeList.contains( languageCode ) ) return inputText;
-            } else return inputText;
-        }
-    }
+    //if ( !m_languageCodeList.isEmpty() )
+    //{
+    //    QString languageCode = talkerCode->languageCode();
+    //    //kDebug() << "StringReplacerProc::convert: converting " << inputText <<
+    //    //    " if language code " << languageCode << " matches " << m_languageCodeList << endl;
+    //    if ( !m_languageCodeList.contains( languageCode ) )
+    //    {
+    //        if ( !talkerCode->countryCode().isEmpty() )
+    //        {
+    //            languageCode += '_' + talkerCode->countryCode();
+    //             //kDebug() << "StringReplacerProc::convert: converting " << inputText << 
+    //             //   " if language code " << languageCode << " matches " << m_languageCodeList << endl;
+    //            if ( !m_languageCodeList.contains( languageCode ) ) return inputText;
+    //        } else return inputText;
+    //    }
+    //}
     // If appId doesn't match, return input unmolested.
     if ( !m_appIdList.isEmpty() )
     {
